pub struct AuthResolver { /* private fields */ }Expand description
A resolver for container registry credentials.
The resolver checks multiple sources in order of precedence to find credentials for a given registry.
Implementations
Sourceimpl AuthResolver
impl AuthResolver
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new resolver with the default Docker config.
Loads the config from DOCKER_CONFIG or ~/.docker/config.json.
If the config doesn’t exist, uses an empty config.
Sourcepub fn with_config(config: DockerConfig) -> Self
pub fn with_config(config: DockerConfig) -> Self
Creates a new resolver with a specific Docker config.
Sourcepub fn with_explicit(self, credential: Credential) -> Self
pub fn with_explicit(self, credential: Credential) -> Self
Sets explicit credentials that override all other sources.
Sourcepub fn resolve(&self, registry: &str) -> Result<Credential>
pub fn resolve(&self, registry: &str) -> Result<Credential>
Resolves credentials for a registry.
Returns the credential to use, following the resolution order:
- Explicit credentials
- Docker config auths
- Registry-specific helper
- Default credential store
- Anonymous
Sourcepub fn resolve_or_anonymous(&self, registry: &str) -> Credential
pub fn resolve_or_anonymous(&self, registry: &str) -> Credential
Resolves credentials for a registry, returning anonymous on any error.
This is useful when you want to try authenticated access but fall back to anonymous if there are any issues with credential resolution.